@@ -244,7 +244,6 @@ static void place_window(void)
 
   if(old_parent != parent)
   {
-    int q;
     XWithdrawWindow(display, victim,
 		    XScreenNumberOfScreen (wattr.screen));
     XSync (display, FALSE);
@@ -332,7 +331,6 @@ static void my_xlockwindow(Display *dpy,
   {
     int mode=PropModeAppend;
     int fmt;
-    XEvent ev;
     unsigned long nitems=0, bytes=0;
     unsigned char *property=0;
     Atom type;
@@ -418,14 +416,14 @@ int main(int argc, char **argv)
   signal(SIGTERM, kill_child);
   signal(SIGWINCH, sigwinch);
 
-  sscanf(argv[1],"%d,%d,%d,%d,%d,%d,%d",
+  sscanf(argv[1],"%d,%d,%lu,%d,%d,%d,%d",
 	 &flags,
 	 &repeats,
-	 &windata.window,
-	 &windata.x,
-	 &windata.y,
-	 &windata.width,
-	 &windata.height);
+	 (long unsigned int *) &windata.window,
+	 (int *)&windata.x,
+	 (int *)&windata.y,
+	 (int *)&windata.width,
+	 (int *)&windata.height);
   file=argv[2];
   winname=argv[3];
   displayname=argv[4];
@@ -491,6 +489,17 @@ int main(int argc, char **argv)
     putenv(foo);
     foo+=strlen(foo)+1;
 
+    /* setup environment variable $width */
+    /* JR, 19.12.2002: Width and height to env! */
+    sprintf(foo,"width=%ld",(long)windata.width);
+    putenv(foo);
+    foo+=strlen(foo)+1;
+
+    /* setup environment variable $height */
+    sprintf(foo,"height=%ld",(long)windata.height);
+    putenv(foo);
+    foo+=strlen(foo)+1;
+
     /* setup environment variable $DISPLAY */
     if(displayname)
     {
