@@ -157,14 +157,14 @@ static void run(NPP instance, const char *file)
 {
   char buffer[1024];
 
-  sprintf(buffer,"%d,%d,%d,%d,%d,%d,%d",
+  sprintf(buffer,"%d,%d,%lu,%d,%d,%d,%d",
 	  THIS->flags,
 	  THIS->repeats,
-	  (int)THIS->windata.window,
-	  (int)THIS->windata.x,
-	  (int)THIS->windata.y,
-	  (int)THIS->windata.width,
-	  (int)THIS->windata.height);
+	  (unsigned long int) THIS->windata.window,
+	  (int) THIS->windata.x,
+	  (int) THIS->windata.y,
+	  (int) THIS->windata.width,
+	  (int) THIS->windata.height);
   D("Executing helper: %s %s %s %s %s %s %s\n",
     helper_fname,
     buffer,
@@ -754,7 +754,10 @@ NPError NPP_NewStream(NPP instance,
 	}
     }
 
-  if((THIS->flags & H_STREAM) && strncasecmp(stream->url,"file:",5))
+  if((THIS->flags & H_STREAM)
+     && strncasecmp(stream->url,"file:",5)
+     && strncasecmp(stream->url,"imap:",5)
+     && strncasecmp(stream->url,"mailbox:",8))
   {
     *stype = NP_NORMAL;
     tempfile = 0;
@@ -827,18 +830,7 @@ void NPP_StreamAsFile(NPP instance,
       D("CHILD RUNNING run() [7]\n");
 
       if(!find_command(instance, 1) && !find_command(instance, 0))
-	{
-	  if(inpath("xmessage"))
-	    {
-	      D("Using xmessage!!!\n");
-	      /* Hard-coded default */
-	      THIS->command="xmessage -buttons '' \"MozPlugger: No appropriate application for type $mimetype found!\"";
-	      THIS->flags = H_REPEATCOUNT | H_FILL | H_SWALLOW | H_IGNORE_ERRORS;
-	      THIS->winname="Xmessage";
-	    }else{
-	      exit(EX_UNAVAILABLE);
-	    }
-	}
+	   _exit(EX_UNAVAILABLE);
 
       D("CHILD RUNNING run() [2]\n");
       run(instance, fname);
