@@ -15,9 +15,6 @@
 #define H_FILL 0x800
 
 #define BUFSIZE 1024*256
-#define PRELOAD 40000
-#define PRELOAD_TIME 5 /* seconds */
-
 
 #define my_timercmp(tvp, cmp, uvp) \
   ( (tvp)->tv_sec == (uvp)->tv_sec ? \
@@ -34,6 +31,7 @@
 
 #define MAXIMUM(X,Y) ((X)>(Y)?(X):(Y))
 #define MINIMUM(X,Y) ((X)<(Y)?(X):(Y))
+
 #ifdef DEBUG
 static FILE *debug_output=0;
 static FILE *getout()
@@ -60,11 +58,9 @@ static void D(char *fmt, ...)
   }
 }
 #else
-/* OPTIMIZE ME! */
 static void D(char *fmt, ...) { }
 #endif
 
-
 #ifndef MIN
 #define MIN(X,Y) ((X)<(Y)?(X):(Y))
 #endif
